@@ -1,4 +1,4 @@
-# $Id: Base.pm,v 1.31.2.5 2003/03/28 20:35:56 joern Exp $
+# $Id: Base.pm,v 1.34 2004/12/11 15:20:14 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Base;
+use Locale::TextDomain qw (video.dvdrip);
 
 use Video::DVDRip::Config;
 use Video::DVDRip::FilterList;
@@ -166,6 +167,8 @@ sub system {
 	my  ($command, $err_ignore, $return_rc) =
 	@par{'command','err_ignore','return_rc'};
 	
+	$self->log ("Executing command: $command");
+	
 	$self->print_debug ("executing command: $command");
 
 	my $catch = `($command) 2>&1`;
@@ -173,7 +176,7 @@ sub system {
 
 	$self->print_debug ("got: rc=$rc catch=$catch");
 
-	croak "Error executing command >$command< : $catch" if $rc;
+	croak "Error executing command $command:\n$catch" if $rc;
 
 	return $return_rc ? $? : $catch;
 }
