@@ -1,13 +1,15 @@
-# $Id: Base.pm,v 1.18 2002/11/01 13:29:19 joern Exp $
+# $Id: Base.pm,v 1.23 2004/04/11 23:36:20 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
+# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
+# All Rights Reserved. See file COPYRIGHT for details.
 # 
 # This module is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::GUI::Base;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Base;
 
@@ -73,7 +75,7 @@ sub cb_commit_file_dialog {
 	
 	if ( -f $filename and $confirm ) {
 		$self->confirm_window (
-			message => "Overwrite existing file '$filename'?",
+			message => __x("Overwrite existing file '{filename}'?", filename => $filename),
 			yes_callback => sub { &$cb($filename); $dialog->destroy },
 			position => 'mouse'
 		);
@@ -105,10 +107,10 @@ sub confirm_window {
 	$hbox->pack_start ($label, 0, 1, 0);
 	$confirm->vbox->pack_start ($hbox, 1, 1, 0);
 	$confirm->border_width(10);
-	$confirm->set_title ("Confirmation");
+	$confirm->set_title (__"Confirmation");
 
 	if ( not $omit_cancel ) {
-		my $cancel = Gtk::Button->new ("Cancel");
+		my $cancel = Gtk::Button->new (__"Cancel");
 		$confirm->action_area->pack_start ( $cancel, 1, 1, 0 );
 		$cancel->signal_connect( "clicked", sub { $confirm->destroy } );
 		$cancel->show;
@@ -143,11 +145,15 @@ sub message_window {
 	my $dialog = Gtk::Dialog->new;
 
 	my $label = Gtk::Label->new ("\n".$message."\n");
-	$dialog->vbox->pack_start ($label, 1, 1, 0);
-	$dialog->border_width(10);
-	$dialog->set_title ("Video::DVDRip Message");
-	$dialog->set_default_size (250, 150);
+	$label->set_justify("left");
 	$label->show;
+	my $hbox = Gtk::HBox->new;
+	$hbox->show;
+	$hbox->pack_start ($label, 0, 1, 0);
+	$dialog->vbox->pack_start ($hbox, 1, 1, 0);
+	$dialog->border_width(10);
+	$dialog->set_title (__"dvd::rip Message");
+	$dialog->set_default_size (250, 150);
 
 	my $ok = Gtk::Button->new ("Ok");
 	$dialog->action_area->pack_start ( $ok, 1, 1, 0 );
@@ -203,6 +209,22 @@ sub create_text_entry {
 	return $hbox;
 }
 
+sub create_tooltip {
+	my $self = shift;
+	my %par = @_;
+	my  ($text, $widget) =
+	@par{'text','widget'};
+
+	return if not $text;
+
+	my $tooltip = Gtk::Tooltips->new;
+	$tooltip->set_tip ($widget, $text, "");
+	$tooltip->enable;
+	$tooltip->set_delay(0);
+	
+	1;
+}
+
 sub create_dialog {
 	my $self = shift;
 	my @fields = @_;
@@ -232,10 +254,10 @@ sub create_dialog {
 		} elsif ( $field->{type} eq 'switch' ) {
 			$hbox = Gtk::HBox->new;
 			$hbox->show;
-			my $radio_yes = Gtk::RadioButton->new ("Yes");
+			my $radio_yes = Gtk::RadioButton->new (__"Yes");
 			$radio_yes->show;
 			$hbox->pack_start($radio_yes, 0, 1, 0);
-			my $radio_no = Gtk::RadioButton->new ("No", $radio_yes);
+			my $radio_no = Gtk::RadioButton->new (__"No", $radio_yes);
 			$radio_no->show;
 			$hbox->pack_start($radio_no, 0, 1, 0);
 
@@ -250,12 +272,15 @@ sub create_dialog {
 					"clicked", sub { &$cb(0) }
 				);
 			}
-			
+
 			if ( $field->{value} ) {
 				$radio_yes->set_active(1);
 			} else {
 				$radio_no->set_active(1);
 			}
+
+			$self->create_tooltip( text => $field->{tooltip}, widget => $radio_no);
+			$self->create_tooltip( text => $field->{tooltip}, widget => $radio_yes);
 			
 		} elsif ( $field->{type} eq 'string' and $field->{presets} ) {
 			my $entry = Gtk::Combo->new;
@@ -271,6 +296,8 @@ sub create_dialog {
 			push @widgets, $entry;
 			$table->attach_defaults ($entry, 1, 2, $i, $i+1);
 
+			$self->create_tooltip( text => $field->{tooltip}, widget => $entry );
+
 		} else {
 			my $entry;
 			$entry = Gtk::Entry->new;
@@ -285,7 +312,10 @@ sub create_dialog {
 			}
 			push @widgets, $entry;
 			$table->attach_defaults ($entry, 1, 2, $i, $i+1);
+
+			$self->create_tooltip( text => $field->{tooltip}, widget => $entry );
 		}
+			
 		++$i;
 	}
 
@@ -302,7 +332,7 @@ sub long_message_window {
 	my ($message) = @par{'message'};
 
 	my $win = Gtk::Window->new;
-	$win->set_title ("Video::DVDRip Message");
+	$win->set_title (__"dvd::rip Message");
 	$win->set_default_size (620, 400);
 	$win->set_position ("center");
 
