@@ -1,4 +1,4 @@
-# $Id: Mplex.pm,v 1.5 2003/01/28 20:19:57 joern Exp $
+# $Id: Mplex.pm,v 1.7 2004/04/11 23:36:20 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::Mplex;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Job;
 
@@ -28,7 +29,8 @@ sub type {
 sub info {
 	my $self = shift;
 
-	my $info = "Multiplexing MPEG - title #".$self->title->nr;
+	my $info = __("Multiplexing MPEG");
+	$info .= " - ".__x("title #{title}", title => $self->title->nr);
 
 	return $info;
 }
@@ -46,7 +48,20 @@ sub init {
 sub get_diskspace_needed {
 	my $self = shift; $self->trace_in;
 
-	return $self->title->tc_target_size * 1024;
+	my $title = $self->title;
+
+	$title->set_actual_chapter($self->chapter);
+
+	my $bc = Video::DVDRip::BitrateCalc->new (
+		title		=> $title,
+		with_sheet	=> 0,
+	);
+
+	$bc->calculate_video_bitrate;
+
+	$title->set_actual_chapter(undef);
+
+	return int(($bc->video_size + $bc->non_video_size)*1024);
 }
 
 sub get_diskspace_freed {
